searchData={"items":[{"type":"module","title":"GettextLLM","doc":"# Gettext LLM","ref":"GettextLLM.html"},{"type":"module","title":"Automated translations - GettextLLM","doc":"Translating from one language to another requires the translator to be accurate and to maintain a consistent tone/persona and style. \nScaling these to multiple languages is challenging. Automated translation with LLM's provide a \"good enough\" alternative in many use cases.\n\n**Elixir Gettext LLM** library allows you to translate all Gettext PO folders/files in your project using any LLM endpoint supported by `langchain`. \nThe library provides several mix tasks that can be run directly in your Elixir/Phoenix project from the command line (ie. locally on the dev machine) or part of a CI/CD pipeline.\n\n`gettext_llm` provides configurable tone/persona and style. This allows you to \"shape\" your resulting translations into something that is compatible with your app audience & brand.","ref":"GettextLLM.html#module-automated-translations"},{"type":"module","title":"Installation - GettextLLM","doc":"The package can be installed by adding `gettext_llm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n      {:gettext_llm, \"0.2.0\", only: [:dev, :test]}\n  ]\nend\n```","ref":"GettextLLM.html#module-installation"},{"type":"module","title":"Usage - GettextLLM","doc":"","ref":"GettextLLM.html#module-usage"},{"type":"module","title":"1. Use `gettext` to extract & merge - GettextLLM","doc":"`gettext_llm` translates PO files. Use `gettext` to extract all the translated messages from your app into POT files & merge them into their respective PO files\n```\nmix gettext.extract\nmix gettext.merge priv/gettext --no-fuzzy\n```","ref":"GettextLLM.html#module-1-use-gettext-to-extract-merge"},{"type":"module","title":"2. Add the `gettext_llm` in your `config.exs` - GettextLLM","doc":"`gettext_llm` uses [langchain](https://github.com/brainlid/langchain) to call the LLM endpoints. As such `gettext_llm` can translate using any LLM endpoint supported by `langchain`. `gettext_llm` reads the endpoint specific config and passes it directly to `langchain`.\n\n#### Example configuration with OpenAI\n```\n# General application configuration\nimport Config\n\nconfig :gettext_llm, GettextLLM,\n  # ignored_languages: [\"en\"] <--- Optional but good to skip translating your reference language \n  persona:\n    \"You are translating messages for a website that connects people needing help with people that can provide help. You will provide translation that is casual but respectful and uses plain language.\",\n  style:\n    \"Casual but respectul. Uses plain plain language that can be understood by all age groups and demographics.\",\n  endpoint: LangChain.ChatModels.ChatOpenAI,\n  endpoint_model: \"gpt-4\",\n  endpoint_temperature: 0,\n  endpoint_config: %{\n    \"openai_key\" =>\n      \" \",\n    \"openai_org_id\" => \" \"\n  }\n```\n\n#### Example configuration with Anthropic\n```\n# General application configuration\nimport Config\n\nconfig :gettext_llm, GettextLLM,\n  # ignored_languages: [\"en\"] <--- Optional but good to skip translating your reference language \n  persona:\n    \"You are translating messages for a website that connects people needing help with people that can provide help. You will provide translation that is casual but respectful and uses plain language.\",\n  style:\n    \"Casual but respectul. Uses plain plain language that can be understood by all age groups and demographics.\",\n  endpoint: LangChain.ChatModels.ChatAnthropic,\n  endpoint_model: \"claude-3-5-sonnet-latest\",\n  endpoint_temperature: 0,\n  endpoint_config: %{\n    \"anthropic_key\" =>\n      \" \"\n  }\n```","ref":"GettextLLM.html#module-2-add-the-gettext_llm-in-your-config-exs"},{"type":"module","title":"3. Run `gettext_llm` mix task - GettextLLM","doc":"#### Run using the default gettext location (ie. priv/gettext)\n```\nmix gettext_llm.translate translate\n```\n\n#### Run using a specific gettext location\n```\nmix gettext_llm.translate translate my_path/gettext \n```","ref":"GettextLLM.html#module-3-run-gettext_llm-mix-task"},{"type":"module","title":"Other `gettext_llm` mix task - GettextLLM","doc":"#### Check that your configuration is correct\n```\nmix gettext_llm.translate info\n```\n\n#### Display help\n```\nmix help gettext_llm.translate \n```","ref":"GettextLLM.html#module-other-gettext_llm-mix-task"},{"type":"module","title":"Documentation - GettextLLM","doc":"Documentation can be be found at  .","ref":"GettextLLM.html#module-documentation"},{"type":"module","title":"Misc - GettextLLM","doc":"For some apps or languages LLM's are not good enough. In these cases you will probably be better off with a human translator. The human translator could work on it's own or part of a hybrind setup. A typical setup has the draft translation version proposed by an LLM and the final approval (and corrections) are performed by the human. Good open source solutions for such a setup are [Kanta](https://github.com/curiosum-dev/kanta) or [Weblate](https://github.com/WeblateOrg/weblate).","ref":"GettextLLM.html#module-misc"},{"type":"module","title":"Thanks - GettextLLM","doc":"Special thanks to [Adrian Codausi](https://github.com/AdrianCDS) & [Goran Codausi](https://github.com/goran-cds) for inspiring me to build this.\nThey have build an earlier prototype of a similar functionality in another project.","ref":"GettextLLM.html#module-thanks"},{"type":"function","title":"GettextLLM.get_config/0","doc":"Loads the `gettext_llm` configuration from the app configuration.","ref":"GettextLLM.html#get_config/0"},{"type":"function","title":"GettextLLM.translate/3","doc":"Translates all the PO files inside the language folders using a specific\ncnfiguration and LLM endpoint.","ref":"GettextLLM.html#translate/3"},{"type":"module","title":"GettextLLM.Gettext","doc":"Gettext folder & file scanning functions.","ref":"GettextLLM.Gettext.html"},{"type":"function","title":"GettextLLM.Gettext.scan_root_folder/1","doc":"Scans the root gettext folder (ie. priv/gettext) and retrieves all the langage\nfolders and the po files inside them.","ref":"GettextLLM.Gettext.html#scan_root_folder/1"},{"type":"module","title":"GettextLLM.Gettext.GettextHelper","doc":"Gettext Test helper. To be moved to the test folder soon.","ref":"GettextLLM.Gettext.GettextHelper.html"},{"type":"function","title":"GettextLLM.Gettext.GettextHelper.cleanup_folder/1","doc":"","ref":"GettextLLM.Gettext.GettextHelper.html#cleanup_folder/1"},{"type":"function","title":"GettextLLM.Gettext.GettextHelper.read_translation_file/3","doc":"","ref":"GettextLLM.Gettext.GettextHelper.html#read_translation_file/3"},{"type":"function","title":"GettextLLM.Gettext.GettextHelper.setup_folder/1","doc":"","ref":"GettextLLM.Gettext.GettextHelper.html#setup_folder/1"},{"type":"module","title":"GettextLLM.Translator.Specs","doc":"Various translation specs for the translators.","ref":"GettextLLM.Translator.Specs.html"},{"type":"type","title":"GettextLLM.Translator.Specs.config/0","doc":"","ref":"GettextLLM.Translator.Specs.html#t:config/0"},{"type":"type","title":"GettextLLM.Translator.Specs.endpoint/0","doc":"","ref":"GettextLLM.Translator.Specs.html#t:endpoint/0"},{"type":"type","title":"GettextLLM.Translator.Specs.opts/0","doc":"","ref":"GettextLLM.Translator.Specs.html#t:opts/0"},{"type":"behaviour","title":"GettextLLM.Translator.Translator","doc":"Translator behavior. Any translators must implement this.","ref":"GettextLLM.Translator.Translator.html"},{"type":"callback","title":"GettextLLM.Translator.Translator.translate/2","doc":"","ref":"GettextLLM.Translator.Translator.html#c:translate/2"},{"type":"module","title":"GettextLLM.Translator.TranslatorLangchain","doc":"Translation functions based on langchain.","ref":"GettextLLM.Translator.TranslatorLangchain.html"},{"type":"function","title":"GettextLLM.Translator.TranslatorLangchain.translate/2","doc":"","ref":"GettextLLM.Translator.TranslatorLangchain.html#translate/2"},{"type":"function","title":"GettextLLM.Translator.TranslatorLangchain.translator_persona_default/0","doc":"","ref":"GettextLLM.Translator.TranslatorLangchain.html#translator_persona_default/0"},{"type":"function","title":"GettextLLM.Translator.TranslatorLangchain.translator_style_default/0","doc":"","ref":"GettextLLM.Translator.TranslatorLangchain.html#translator_style_default/0"},{"type":"module","title":"GettextLLM.Translator.TranslatorTest","doc":"Various translation functions for testing purposes.","ref":"GettextLLM.Translator.TranslatorTest.html"},{"type":"function","title":"GettextLLM.Translator.TranslatorTest.translate/2","doc":"","ref":"GettextLLM.Translator.TranslatorTest.html#translate/2"},{"type":"task","title":"mix gettext_llm.translate","doc":"GettextLLM usage:\n * Translate using default gettext folder (priv/gettext)\n    ```\n    mix gettext_llm.translate translate\n    ```\n\n * Translate using specific gettext folder\n    ```\n    mix gettext_llm.translate translate my_path/gettext\n    ```\n\n * Display info (including current configuration)\n    ```\n    mix gettext_llm.translate info\n    ```\n\n * Display help\n    ```\n    mix help gettext_llm.translate\n    ```","ref":"Mix.Tasks.GettextLlm.Translate.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}